0.9.9 API documentation: GLM_EXT_vector_ulp

| 0.9.9 API documentation

- Main Page
- Modules
- Files

GLM_EXT_vector_ulp
Stable extensions

Allow the measurement of the accuracy of a function against a reference implementation. More...

Allow the measurement of the accuracy of a function against a reference implementation.

This extension works on floating-point data and provide results in ULP.

Include <glm/ext/vector_ulp.hpp> to use the features of this extension.

See also
  GLM_EXT_scalar_ulp
  GLM_EXT_scalar_relational
  GLM_EXT_vector_relational